@@ -11,7 +11,7 @@ def read_version(versionfile=DEFAULT_FILE):
     try:
         with open(versionfile) as f:
             return f.read().strip()
-    except IOError:
+    except IOError:  # pragma: no cover
         logger.error('Running an unknown version of senpy. Be careful!.')
         return '0.0'
 
